@@ -428,8 +428,6 @@ func (root *Root) setSectionStart(input string) {
 
 // setMultiColor set multiple strings to highlight with multiple colors.
 func (root *Root) setMultiColor(input string) {
-	m := root.Doc
-
 	quoted := false
 	f := strings.FieldsFunc(input, func(r rune) bool {
 		if r == '"' {
@@ -438,16 +436,7 @@ func (root *Root) setMultiColor(input string) {
 		return !quoted && r == ' '
 	})
 
-	m.stringsMultiColor = nil
-	for _, w := range f {
-		s, err := strconv.Unquote(w)
-		if err != nil {
-			s = w
-		}
-		reg := regexpCompile(s, true)
-		m.stringsMultiColor = append(m.stringsMultiColor, reg)
-	}
-
+	root.Doc.setMultiColorWords(f)
 	root.setMessagef("Set multicolor strings [%s]", input)
 }
 
