@@ -1,7 +1,6 @@
 package oviewer
 
 import (
-	"bytes"
 	"os"
 	"reflect"
 	"testing"
@@ -466,7 +465,7 @@ func Test_csToStyle(t *testing.T) {
 	t.Parallel()
 	type args struct {
 		style        tcell.Style
-		csiParameter *bytes.Buffer
+		csiParameter string
 	}
 	tests := []struct {
 		name string
@@ -477,7 +476,7 @@ func Test_csToStyle(t *testing.T) {
 			name: "color8bit",
 			args: args{
 				style:        tcell.StyleDefault,
-				csiParameter: bytes.NewBufferString("38;5;1"),
+				csiParameter: "38;5;1",
 			},
 			want: tcell.StyleDefault.Foreground(tcell.ColorMaroon),
 		},
@@ -485,7 +484,7 @@ func Test_csToStyle(t *testing.T) {
 			name: "color8bit2",
 			args: args{
 				style:        tcell.StyleDefault,
-				csiParameter: bytes.NewBufferString("38;5;21"),
+				csiParameter: "38;5;21",
 			},
 			want: tcell.StyleDefault.Foreground(tcell.GetColor("#0000ff")),
 		},
@@ -493,14 +492,14 @@ func Test_csToStyle(t *testing.T) {
 			name: "attributes",
 			args: args{
 				style:        tcell.StyleDefault,
-				csiParameter: bytes.NewBufferString("2;3;4;5;6;7;8;9"),
+				csiParameter: "2;3;4;5;6;7;8;9",
 			},
 			want: tcell.StyleDefault.Dim(true).Italic(true).Underline(true).Blink(true).Reverse(true).StrikeThrough(true),
 		},
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
-			if got := csToStyle(tt.args.style, tt.args.csiParameter.String()); !reflect.DeepEqual(got, tt.want) {
+			if got := csToStyle(tt.args.style, tt.args.csiParameter); !reflect.DeepEqual(got, tt.want) {
 				t.Errorf("csToStyle() = %v, want %v", got, tt.want)
 				gfg, gbg, gattr := got.Decompose()
 				wfg, wbg, wattr := tt.want.Decompose()
