@@ -7,6 +7,7 @@ import (
 	"io/fs"
 	"os"
 	"regexp"
+	"strconv"
 	"sync"
 	"sync/atomic"
 	"time"
@@ -94,8 +95,8 @@ type Document struct {
 
 	// Last moved Section position.
 	lastSectionPosNum int
-	// Multiple strings with multicolor highlighting.
-	stringsMultiColor []*regexp.Regexp
+	// multiColorRegexps holds multicolor regular expressions in slices.
+	multiColorRegexps []*regexp.Regexp
 
 	// mu controls the mutex.
 	mu sync.Mutex
@@ -279,11 +280,11 @@ func (m *Document) firstLine() int {
 	return m.SkipLines + m.Header
 }
 
-// SearchLine searches the document and returns the matching line.
-func (m *Document) SearchLine(ctx context.Context, searcher Searcher, num int) (int, error) {
-	num = max(num, 0)
-
-	for n := num; n < m.BufEndNum(); n++ {
+// SearchLine searches the document and returns the matching line number.
+func (m *Document) SearchLine(ctx context.Context, searcher Searcher, lN int) (int, error) {
+	lN = max(lN, 0)
+	end := m.BufEndNum()
+	for n := lN; n < end; n++ {
 		if searcher.Match(m.GetLine(n)) {
 			return n, nil
 		}
@@ -297,11 +298,11 @@ func (m *Document) SearchLine(ctx context.Context, searcher Searcher, num int) (
 	return 0, ErrNotFound
 }
 
-// BackSearchLine does a backward search on the document and returns a matching line.
-func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, num int) (int, error) {
-	num = min(num, m.BufEndNum()-1)
+// BackSearchLine does a backward search on the document and returns a matching line number.
+func (m *Document) BackSearchLine(ctx context.Context, searcher Searcher, lN int) (int, error) {
+	lN = min(lN, m.BufEndNum()-1)
 
-	for n := num; n >= 0; n-- {
+	for n := lN; n >= 0; n-- {
 		if searcher.Match(m.GetLine(n)) {
 			return n, nil
 		}
@@ -332,3 +333,16 @@ func (m *Document) setSectionDelimiter(delm string) {
 	m.SectionDelimiter = delm
 	m.SectionDelimiterReg = regexpCompile(delm, true)
 }
+
+// setMultiColor set multiple strings to highlight with multiple colors.
+func (m *Document) setMultiColorWords(words []string) {
+	m.multiColorRegexps = nil
+	for _, w := range words {
+		s, err := strconv.Unquote(w)
+		if err != nil {
+			s = w
+		}
+		reg := regexpCompile(s, true)
+		m.multiColorRegexps = append(m.multiColorRegexps, reg)
+	}
+}
