@@ -193,6 +193,8 @@ type Config struct {
 	// AfterWriteOriginal specifies the number of lines after the current position.
 	// 0 specifies the bottom of the screen.
 	AfterWriteOriginal int
+	// MultiColorWords specifies words to color separated by spaces.
+	MultiColorWords []string
 
 	// QuiteSmall Quit if the output fits on one screen.
 	QuitSmall bool
@@ -368,7 +370,7 @@ func NewConfig() Config {
 			Background: "darkgoldenrod",
 		},
 		StyleSectionLine: OVStyle{
-			Background: "green",
+			Background: "slateblue",
 		},
 		StyleMultiColorHighlight: []OVStyle{
 			{Foreground: "red"},
@@ -554,12 +556,18 @@ func (root *Root) Run() error {
 	if !root.Config.DisableMouse {
 		root.Screen.EnableMouse(MouseFlags)
 	}
+
 	root.Config.General.SectionDelimiterReg = regexpCompile(root.Config.General.SectionDelimiter, true)
 
 	root.optimizedMan()
 
 	for n, doc := range root.DocList {
 		doc.general = root.Config.General
+
+		if root.Config.MultiColorWords != nil {
+			doc.setMultiColorWords(root.Config.MultiColorWords)
+		}
+
 		w := ""
 		if doc.general.WatchInterval > 0 {
 			doc.watchMode()
